==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiCore/QVariant_shell.h <==
#ifndef QVARIANT_SHELL_H
#define QVARIANT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtCore/qvariant.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QScopeGuard>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbitarray.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qdatetime.h>
#if QT_CONFIG(easingcurve)
#include <QtCore/qeasingcurve.h>
#endif //QT_CONFIG(easingcurve)
#include <QtCore/qjsonarray.h>
#include <QtCore/qjsondocument.h>
#include <QtCore/qjsonobject.h>
#include <QtCore/qjsonvalue.h>
#include <QtCore/qline.h>
#include <QtCore/qlocale.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qurl.h>
#include <QtCore/quuid.h>
#include <QtJambi/CoreAPI>
#include <QtJambi/JavaAPI>
#include <QtJambi/RegistryAPI>


class QVariant_shell : public QVariant
{
public:

private:
};

struct QVariant_access : public QVariant
{
    jboolean __qt_cmp_cref_QVariant_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject other0) const;
    jint __qt_compare_cref_QVariant_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject other0) const;
    jobject __qt_convertTo_const_int_void_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint t0) const;
    void __qt_create_int_const_void_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jobject copy1);
};

#endif // QVARIANT_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiCore/QVariant_shell.h <==
#ifndef QVARIANT_SHELL_H
#define QVARIANT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCore/qvariant.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QScopeGuard>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbitarray.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcompare.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qdebug.h>
#if QT_CONFIG(easingcurve)
#include <QtCore/qeasingcurve.h>
#endif //QT_CONFIG(easingcurve)
#include <QtCore/qjsonarray.h>
#include <QtCore/qjsondocument.h>
#include <QtCore/qjsonobject.h>
#include <QtCore/qjsonvalue.h>
#include <QtCore/qline.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmetatype.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qurl.h>
#include <QtCore/quuid.h>
#include <QtJambi/CoreAPI>
#include <QtJambi/JavaAPI>
#include <QtJambi/RegistryAPI>


class QVariant_shell : public QVariant
{
public:

private:
};

struct QVariant_access : public QVariant
{
    jobject __qt_convertTo_int_void_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0) const;
    void __qt_create_QMetaType_const_void_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID type0, jobject copy1);
    void __qt_create_int_const_void_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jobject copy1);
};

#endif // QVARIANT_SHELL_H
